pub fn build_function_registry(extra_specs: &[FunctionSpec]) -> FunctionRegistryExpand description
Builds a function registry from the builtin specs plus caller-provided
extension specs (e.g. \eval registered by the eval package).
pub fn build_function_registry(extra_specs: &[FunctionSpec]) -> FunctionRegistryBuilds a function registry from the builtin specs plus caller-provided
extension specs (e.g. \eval registered by the eval package).