pub fn join_with_spacing(
items: &[SpacableItem],
tight: bool,
spec: &SpacingSpec,
) -> StringExpand description
Join spacable items into a string, inserting spacing between adjacent
non-space atoms according to the given SpacingSpec.
pub fn join_with_spacing(
items: &[SpacableItem],
tight: bool,
spec: &SpacingSpec,
) -> StringJoin spacable items into a string, inserting spacing between adjacent
non-space atoms according to the given SpacingSpec.