pub fn token_location(token: Option<&Token>) -> Option<SourceLocation>Expand description
Returns the source location of a token, if any.
pub fn token_location(token: Option<&Token>) -> Option<SourceLocation>Returns the source location of a token, if any.